/*
 * JBoss, Home of Professional Open Source
 * Copyright 2005, JBoss Inc., and individual contributors as indicated
 * by the @authors tag. See the copyright.txt in the distribution for a
 * full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */
package org.jboss.osgi.blueprint.parser.xb;

// $Id: TReference.java 91345 2009-07-16 14:16:10Z thomas.diesler@jboss.com $

import java.math.BigInteger;

import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlType;

import org.jboss.osgi.blueprint.BlueprintContext;

/**
 * The Treference type defines the <reference> element.  These
 * are instances of the TserviceReference type, with the addition
 * of a timeout attribute.  If the timeout is not specified,
 * the default-timeout value is inherited from the encapsulating
 * <blueprint> definition.
 * 
 * <xsd:complexType name="Treference">
 *  <xsd:complexContent>
 *    <xsd:extension base="TserviceReference">
 *      <xsd:sequence>
 *        <xsd:any namespace="##other" minOccurs="0" maxOccurs="unbounded" processContents="strict" />
 *      </xsd:sequence>
 *      <xsd:attribute name="timeout" type="Ttimeout" />
 *    </xsd:extension>
 *  </xsd:complexContent>
 * </xsd:complexType>
 * 
 * @author thomas.diesler@jboss.com
 * @since 13-May-2009
 */

// [JBXB-210] Property order cannot be defined on super type
// https://jira.jboss.org/jira/browse/JBXB-210
// @XmlType(name = "Treference", namespace = BlueprintContext.XMLNS_BLUEPRINT)

@XmlType(name = "Treference", namespace = BlueprintContext.XMLNS_BLUEPRINT, propOrder = { "description", "referenceListeners" })
public class TReference extends TServiceReference
{
   protected BigInteger timeout;

   @XmlAttribute
   public long getTimeout()
   {
      return timeout.longValue();
   }

   public void setTimeout(BigInteger value)
   {
      this.timeout = value;
   }
}
